@@ -10,6 +10,7 @@ import matplotlib.cm as cm
 from hoki.utils.exceptions import HokiFatalError, HokiUserWarning, HokiFormatError
 import warnings
 from hoki.utils.hoki_object import HokiObject
+import copy
 
 
 class HRDiagram(HokiObject):
@@ -139,11 +140,14 @@ class HRDiagram(HokiObject):
         self._all_H = self.low_H + self.medium_H + self.high_H
 
         # Initialise attributes for later
+        self.reset_stack()
 
+    def reset_stack(self):
         self.high_H_stacked, self.medium_H_stacked, self.low_H_stacked = np.zeros((100, 100)), \
-                                                                         np.zeros((100, 100)),\
+                                                                         np.zeros((100, 100)), \
                                                                          np.zeros((100, 100))
         self.all_stacked = None
+        print("Stack has been reset")
 
     def stack(self, log_age_min=None, log_age_max=None):
         """
@@ -164,6 +168,7 @@ class HRDiagram(HokiObject):
             self.medium_H_stacked, self.low_H_stacked and self.all_stacked.
 
         """
+        self.reset_stack()
 
         if log_age_min is None and log_age_max is not None:
             log_age_min = self.t[0]
@@ -259,6 +264,7 @@ class HRDiagram(HokiObject):
 
 
         """
+
         #assert abundances != (0, 0, 0), "HOKI ERROR: abundances cannot be (0, 0, 0) - You're plotting nothing."
         if abundances == (0, 0, 0):
             raise HokiFatalError("Abundances cannot be (0, 0, 0) - You're plotting nothing.")
@@ -299,15 +305,14 @@ class HRDiagram(HokiObject):
 
             return hr_plot
 
+        elif age_range is not None and log_age is not None:
+            error_message = "You provided an age range as well as an age. The former takes " \
+                            "precedent. If you wanted to plot a single age, this will be WRONG."
+            warnings.warn(error_message, HokiUserWarning)
+
         # Case where an age or age_range is given
 
-        if log_age:
-            if not isinstance(log_age, int) and not isinstance(log_age, float):
-                raise HokiFormatError("Age should be an int or float")
-
-            all_hr, high_hr, medium_hr, low_hr = self.at_log_age(log_age)
-
-        elif age_range:
+        if age_range is not None:
             if not isinstance(age_range, list) and not isinstance(age_range, tuple):
                 raise HokiFormatError("Age range should be a list or a tuple")
 
@@ -315,10 +320,13 @@ class HRDiagram(HokiObject):
             all_hr, high_hr, medium_hr, low_hr = self.all_stacked, self.high_H_stacked, \
                                                  self.medium_H_stacked, self.low_H_stacked
 
-        elif age_range and log_age:
-            error_message = "You provided an age range as well as an age. The former takes "\
-                            "precedent. If you wanted to plot a single age, this will be WRONG."
-            warnings.warn(error_message, HokiUserWarning)
+        elif log_age is not None:
+            if not isinstance(log_age, int) and not isinstance(log_age, float):
+                raise HokiFormatError("Age should be an int or float")
+
+            all_hr, high_hr, medium_hr, low_hr = self.at_log_age(log_age)
+
+
 
         if abundances == (1, 1, 1):
             hr_plot = plot_hrdiagram(all_hr, kind=self.type, **kwargs)
@@ -353,6 +361,8 @@ class HRDiagram(HokiObject):
     # Now we can index HR diagrams!
     def __getitem__(self, item):
         return self._all_H[item]
+        #return self.low_H[item]
+        #return self.high_H[item]+self.medium_H[item]
 
 
 def plot_hrdiagram(single_hr_grid, kind='TL', loc=111, cmap='Greys', **kwargs):
@@ -430,7 +440,7 @@ def plot_hrdiagram(single_hr_grid, kind='TL', loc=111, cmap='Greys', **kwargs):
     # to make sure the colourmap is sensible we want to ensure the minimum level == minimum value
     levels = [min_level] + [level for level in possible_levels if level > min_level]
 
-    colMap = cm.get_cmap(cmap)
+    colMap = copy.copy(cm.get_cmap(cmap))
 
     colMap.set_under(color='white')
 
