@@ -10,8 +10,9 @@ import yaml
 import io
 import pickle
 import pkg_resources
+import hoki.data_compilers
 import warnings
-from hoki.utils.exceptions import HokiDeprecationWarning
+from hoki.utils.exceptions import HokiDeprecationWarning, HokiKeyError
 
 # TODO: Should I allow people to chose to load the data into a numpy arrays as well or is the
 #       data frame good enough?
@@ -73,9 +74,9 @@ def set_models_path(path):
 ########################
 
 
-def dummy_to_dataframe(filename):
+def dummy_to_dataframe(filename, bpass_version=DEFAULT_BPASS_VERSION):
     """Reads in dummy to df from a filename"""
-    inv_dict ={v: k for k, v in dummy_dicts[DEFAULT_BPASS_VERSION].items()}
+    inv_dict ={v: k for k, v in dummy_dicts[bpass_version].items()}
     cols = [inv_dict[key] if key in inv_dict.keys() else 'Nan'+str(key) for key in range(96)]
     dummy = pd.read_csv(filename, names=cols, sep=r"\s+", engine='python')
     return dummy
@@ -99,7 +100,7 @@ def model_input(path):
     """
 
     assert isinstance(path, str), "The location of the file is expected to be a string."
-    assert os.path.isfile(path), "This file does not exist, or its path is incorrect."
+    assert os.path.isfile(path), f"File {path} does not exist, or its path is incorrect."
 
     lines = open(path).read().split("\n")
 
@@ -410,6 +411,242 @@ def _UV_nebular_lines(path):
 
     return pd.read_csv(path, skiprows=1, sep=r'\s+', engine='python', names=column_UV_em_lines)
 
+
+
+#####################################
+#  BPASS Load over all metallicity  #
+#####################################
+
+def rates_all_z(data_path, imf, binary=True):
+    """
+    Loads the BPASS supernova event files.
+
+    Notes
+    -----
+    The rates are just read from file and not normalised.
+
+    Input
+    -----
+    data_path : `str`
+        The filepath to the folder containing the BPASS data
+
+    binary : `bool`
+        Use the binary files or just the single stars. Default=True
+
+    imf : `str`
+        BPASS Identifier of the IMF to be used.
+        The accepted IMF identifiers are:
+        - `"imf_chab100"`
+        - `"imf_chab300"`
+        - `"imf100_100"`
+        - `"imf100_300"`
+        - `"imf135_100"`
+        - `"imf135_300"`
+        - `"imfall_300"`
+        - `"imf170_100"`
+        - `"imf170_300"`
+
+    Returns
+    -------
+    `pandas.DataFrame` (51, (8,13)) (log_age, (event_types, metallicity)
+        A pandas MultiIndex dataframe containing the BPASS number of events
+        per metallicity per type.
+        Usage:   rates.loc[log_age, (type, metallicity)]
+        Example: rates.loc[6.5, ("Ia", 0.02)]
+
+
+        Notes
+        -----
+        This dataframe has the following structure.
+        The index is the log_age as a float.
+        The column is a `pandas.MultiIndex` with the event types
+        (level=0, `float`) and the metallicity (level=1, `float`)
+
+        |Event Type | Ia      | IIP      |  ... | PISNe | low_mass |
+        |Metallicity| 0.00001 | 0.00001  |  ... |  0.04 |    0.04  |
+        | log_age   |---------|----------|------|-------|----------|
+        |    6.0    |
+        |    ...    |                  Event Rate values
+        |    11.0   |
+
+    """
+
+    # Check population type
+    star = "bin" if binary else "sin"
+
+    # Check if the given IMF is in the accepted IMFs
+    if imf not in BPASS_IMFS:
+        raise HokiKeyError(
+            f"{imf} is not a BPASS IMF. Please select a correct IMF.\n"\
+            "These can be found in the documentation of this function.")
+
+    # Create the output DataFrame
+    arrays = [BPASS_NUM_METALLICITIES, BPASS_EVENT_TYPES]
+    columns = pd.MultiIndex.from_product(
+        arrays, names=["Metallicicty", "Event Type"])
+
+    rates = pd.DataFrame(index=BPASS_TIME_BINS,
+                         columns=columns,
+                         dtype=np.float64)
+    rates.index.name = "log_age"
+
+    # load supernova count files
+    for num, metallicity in enumerate(BPASS_METALLICITIES):
+        data = model_output(
+            f"{data_path}/supernova-{star}-{imf}.{metallicity}.dat"
+        )
+        data = data.loc[:, slice(BPASS_EVENT_TYPES[0], BPASS_EVENT_TYPES[-1])]
+
+        rates.loc[:, (BPASS_NUM_METALLICITIES[num], slice(None))] = data.to_numpy()
+
+    # swap metallicity and event type
+    return rates.swaplevel(0, 1, axis=1)
+
+
+def spectra_all_z(data_path, imf, binary=True):
+    """
+    Load all BPASS spectra from files.
+
+    Notes
+    -----
+    The first time this function is ran on a folder it will generate a pickle
+    file containing all the BPASS spectra per metallicity for faster loading
+    in the future. It stores the file in the same folder with the name:
+    `all_spectra-[bin/sin]-[imf].pkl`
+
+    The spectra are just read from file and not normalised.
+
+
+    Input
+    -----
+    data_path : `str`
+        The path to the folder containing the BPASS spectra.
+
+    binary : `bool`
+        Use the binary files or just the single stars. Default=True
+
+    imf : `str`
+        BPASS Identifier of the IMF to be used.
+        The accepted IMF identifiers are:
+        - `"imf_chab100"`
+        - `"imf_chab300"`
+        - `"imf100_100"`
+        - `"imf100_300"`
+        - `"imf135_100"`
+        - `"imf135_300"`
+        - `"imfall_300"`
+        - `"imf170_100"`
+        - `"imf170_300"`
+
+
+    Returns
+    -------
+    spectra : `numpy.ndarray` (13, 51, 100000) [(metallicity, log_age, wavelength)]
+        A 3D numpy array containing all the BPASS spectra for a specific imf
+        and binary or single star population.
+        Usage: spectra[1][2][1000]
+                (gives L_\\odot for Z=0.0001 and log_age=6.2 at 999 Angstrom)
+
+    """
+    # Check population type
+    star = "bin" if binary else "sin"
+
+    # check IMF key
+    if imf not in BPASS_IMFS:
+        raise HokiKeyError(
+            f"{imf} is not a BPASS IMF. Please select a correct IMF.")
+
+    # check if data_path is a string
+    if not isinstance(data_path, str):
+         raise HokiTypeError("The folder location is expected to be a string.")
+
+    # check if compiled file exists
+    if os.path.isfile(f"{data_path}/all_spectra-{star}-{imf}.npy"):
+        print("Loading precompiled file.")
+        spectra = np.load(f"{data_path}/all_spectra-{star}-{imf}.npy")
+        print("Done Loading.")
+    # Otherwise compile
+    else:
+        print("Compiled file not found. Data will be compiled")
+        spec = hoki.data_compilers.SpectraCompiler(
+            data_path, data_path, imf, binary=binary
+        )
+        spectra = spec.output
+    return spectra
+
+
+def emissivities_all_z(data_path, imf, binary=True):
+    """
+    Load all BPASS emissivities from files.
+
+    Notes
+    -----
+    The first time this function is run on a folder it will generate an npy
+    file containing all the BPASS emissivities for faster loading in the
+    future. It stores the file in the same folder with the name:
+    `all_ionizing-[bin/sin]-[imf].npy`.
+
+    The emissivities are just read from file and not normalised.
+
+
+    Input
+    -----
+    data_path : `str`
+        The path to the folder containing the BPASS files.
+
+    binary : `bool`
+        Use the binary files or just the single stars. Default=True
+
+    imf : `str`
+        BPASS Identifier of the IMF to be used.
+        The accepted IMF identifiers are:
+        - `"imf_chab100"`
+        - `"imf_chab300"`
+        - `"imf100_100"`
+        - `"imf100_300"`
+        - `"imf135_100"`
+        - `"imf135_300"`
+        - `"imfall_300"`
+        - `"imf170_100"`
+        - `"imf170_300"`
+
+    Returns
+    -------
+    emissivities : `numpy.ndarray` (N_Z, N_age, 4) [(metallicity, log_age, band)]
+        A 3D numpy array containing all the BPASS emissivities (Nion [1/s],
+        L_Halpha [ergs/s], L_FUV [ergs/s/A], L_NUV [ergs/s/A]) for a specific
+        imf and binary or single star population.
+        Usage: spectra[1][2][0]
+                (gives Nion for Z=0.0001 and log_age=6.2)
+    """
+    # Check population type
+    star = "bin" if binary else "sin"
+
+    # check IMF key
+    if imf not in BPASS_IMFS:
+        raise HokiKeyError(
+            f"{imf} is not a BPASS IMF. Please select a correct IMF.")
+
+    # check if data_path is a string
+    if not isinstance(data_path, str):
+         raise HokiTypeError("The folder location is expected to be a string.")
+
+    # Check if compiled spectra are already present in data folder
+    if os.path.isfile(f"{data_path}/all_ionizing-{star}-{imf}.npy"):
+        print("Load precompiled file.")
+        emissivities = np.load(f"{data_path}/all_ionizing-{star}-{imf}.npy")
+        print("Done Loading.")
+
+    # Compile the spectra for faster reading next time otherwise
+    else:
+        print("Compiled file not found. Data will be compiled.")
+        res = hoki.data_compilers.EmissivityCompiler(
+            data_path, data_path, imf, binary=binary
+        )
+        emissivities = res.output
+    return emissivities
+
+
 #################
 #               #
 #################
@@ -417,4 +654,4 @@ def _UV_nebular_lines(path):
 def _do_not_use():
     import webbrowser
     url = "https://www.youtube.com/watch?v=dQw4w9WgXcQ"
-    webbrowser.open_new_tab(url)
\ No newline at end of file
+    webbrowser.open_new_tab(url)
